'use strict';
import convert from 'koa-convert'
import Cors from '@koa/cors'
import bodyParser from 'koa-bodyparser'
import Helmet from 'koa-helmet'
import respond from 'koa-respond'
import jwt from 'koa-jwt'
import compose from 'koa-compose';
import cors from 'kcors';
import serve from 'koa-static';
import logger from 'koa-logger';
import mount from 'koa-mount';
import session from 'koa-generic-session';
import views from 'koa-views';

import _ from './passport';
import passport from 'koa-passport';
import log4js from 'log4js';
import config from "./index.js";

export default function middleware(app) {

  app.proxy = true;

  log4js.configure({
    // appenders: [
    //     { type: 'console' },
    //     { type: 'dateFile', filename: __dirname + '/../tmp/boilerplate.log' , "pattern":"-yyyy-MM-dd-hh.log","alwaysIncludePattern":false, category: 'file' }
    // ],
    appenders: {cheese: {type: 'file', filename: 'cheese.log'}},
    categories: {default: {appenders: ['cheese'], level: 'error'}},
    replaceConsole: true
  });

  app.use(cors({credentials: true}));
  app.use(convert(logger()))
  // app.use(jwt({
  //   secret: config.jwt.secret,
  // }).unless({
  //   path: [/\/api/, /\/login/],
  // }))

// 安全内容控制，添加常见的安全防护
  app.use(Helmet())
  app.use(Cors())
  app.use(bodyParser({
    enableTypes: ['json'],
    jsonLimit: '10mb',
    strict: true,
    onerror: function (err, ctx) {
      if (err) {
        console.log(err)
      }
      ctx.throw('body parse error', 422)
    }
  }))

  app.use(respond())
  // app.use(mount("/", convert(Serve(__dirname + '/../public/'))));
  app.use(serve(__dirname + '/../../public'))
  app.use(serve(__dirname + '/../../dist'))

  app.keys = ['superalsrk-session-key'];
  app.use(convert(session()))

  app.use(passport.initialize())
  app.use(passport.session())

  // app.use(views(__dirname + '/../views', {extension: 'swig'}))
  app.use(views(__dirname + '/../views', {extension: 'ejs'}))
  app.context.state = {}
  app.context.state = Object.assign(app.context.state, {config : config});
  // app.context.state = app.context.state ? Object.assign(app.context.state, {config : config}):{config : config};
}
