import mongoose from 'mongoose'
import nanoid from "nanoid";
import bcrypt from 'bcrypt'
import jsonwebtoken from 'jsonwebtoken'

const User = mongoose.model('user');

class LoginController {

  /** you can login with
   * curl -X POST http://localhost:3200/api/login/ -H 'cache-control: no-cache' -H 'content-type: application/x-www-form-urlencoded' -d 'username=superman2&password=123456'
   */
  async login(ctx) {
    const { body } = ctx.request
    try {
      const user = await User.findOne({ username: body.username });
      if (!user) {
        ctx.status = 401
        ctx.body = {
          message: '用户名错误',
        }
        return;
      }
      // 匹配密码是否相等
      if (await bcrypt.compare(body.password, user.password)) {
        ctx.status = 200
        ctx.body = {
          message: '登录成功',
          user: user.userInfo,
          // 生成 token 返回给客户端
          token: jsonwebtoken.sign({
            data: user,
            // 设置 token 过期时间
            exp: Math.floor(Date.now() / 1000) + (60 * 60), // 60 seconds * 60 minutes = 1 hour
          }, secret),
        }
      } else {
        ctx.status = 401
        ctx.body = {
          message: '密码错误',
        }
      }
    } catch (error) {
      ctx.throw(500)
    }
  }

  /**
   * you can register with
   * curl -X POST http://localhost:3200/api/register  -H 'cache-control: no-cache' -H 'content-type: application/x-www-form-urlencoded'  -d 'username=superman2&password=123456'
   */
  async register(ctx) {
    const { body } = ctx.request;
    try {
      if (!body.username || !body.password) {
        ctx.status = 400;
        ctx.body = {
          error: `expected an object with username, password but got: ${body}`,
        }
        return;
      }
      body.password = await bcrypt.hash(body.password, 5)
      let user = await User.find({ username: body.username });
      if (!user.length) {
        const newUser = new User(body);
        user = await newUser.save();
        ctx.status = 200;
        ctx.body = {
          message: '注册成功',
          user,
        }
      } else {
        ctx.status = 406;
        ctx.body = {
          message: '用户名已经存在',
        }
      }
    } catch (error) {
      ctx.throw(500)
    }
  }

}

export default new LoginController();
//
// export const register = async (ctx, next) => {
//   if (ctx.request.body && ctx.request.body.username && ctx.request.body.password && ctx.request.body.email) {
//     const user = ctx.request.body;
//
//     let resultOld = await UserModel.findOne({email: user.email})
//
//     if (resultOld) {
//       ctx.body = {
//         success: true,
//         message: "email already exist"
//       }
//       ctx.end()
//     }
//
//     const userEntity = await UserModel({
//       username: user.username,
//       password: user.password,
//       email: user.email,
//       phoneNumber: user.phoneNumber
//     });
//     let result = await userEntity.save().catch(err => {
//       ctx.throw(500, err);
//     });
//     ctx.body = {
//       success: true,
//       message: "new user success",
//       data: result
//     }
//   } else {
//     ctx.status = 403
//     ctx.body = {
//       success: false,
//       data: null
//     }
//   }
// }
//
// export const createUser = async (ctx, next) => {
//   if (ctx.request.body && ctx.request.body.username && ctx.request.body.password) {
//     const user = ctx.request.body;
//
//     const campaignEntity = await CampaignModel({
//       campaignName: user.name,
//       campaignNickName: user.nickname,
//       campaignUrl: user.url,
//       campaignCode: nanoid(6),
//       meta: {
//         og_title: campaign.meta.og_title,
//         og_image: campaign.meta.og_image,
//         og_site_name: campaign.meta.og_site_name,
//         og_url: campaign.meta.og_url,
//         og_type: campaign.meta.og_type,
//         description: campaign.meta.description,
//         title: campaign.meta.title,
//       }
//     });
//     let result = await campaignEntity.save().catch(err => {
//       ctx.throw(500, err);
//     });
//     ctx.body = {
//       success: true,
//       data: result
//     }
//   } else {
//     ctx.status = 403
//     ctx.body = {
//       success: false,
//       data: null
//     }
//   }
// }
