

import validator from 'validator';
import { CampaignModel, KeywordsModel } from '../../schemas';
import KeywordsSchema from '../../schemas/keywords';

// import uuid from 'uuid';


class KeyWordController {
  constructor() {
  }

  
  /**
   * 添加关键词，设置一天之内的使用次数
   * 随机规则，根据关键次一天使用限制次数进行分配
   * @param ctx {活动code，关键词，关键词次数，关键词阀值类型}
   * @returns {Promise<void>}
   */
  async addKeyWord(ctx) {
    try {
      const { body } = ctx.request;
      const { campaignCode, content, VPT,VPTType,VPTCount } = body;

      if (!campaignCode
        || !content
        || !VPT) {
        ctx.send(400, {
          resultCode: 0,
          errorCode: 1,
          serverTime: +new Date(),
          message: 'fault',
          data: {},
        });
        return;
      }

      const KeywordsModel = ctx.models('keywords');

      const keywordsEntity = new KeywordsModel({
        campaignCode,
        content,
        VPT,
        VPTType,
        VPTCount
      });
      const result = await keywordsEntity.save();

      ctx.send(200, {
        resultCode: 1,
        errorCode: 0,
        serverTime: +new Date(),
        message: 'success',
        data: result,
      });
    } catch (error) {
      console.log(error);
      ctx.send(500, {
        resultCode: 0,
        errorCode: 1,
        serverTime: +new Date(),
        message: error.toString(),
        data: null,
      });
    }
  }

  /**
   * 获取关键词，
   * 随机规则，根据关键次一天使用限制次数进行分配
   * @param ctx {活动code，随机类型}
   * @returns {Promise<void>}
   */
  async getKeyWord(ctx) {
    try {
      const { query } = ctx.request;
      const { campaignCode,rewardGetten } = query;

      if (!campaignCode) {
        ctx.send(400, {
          resultCode: 0,
          errorCode: 1,
          serverTime: +new Date(),
          message: 'fault',
          data: {},
        });
        return;
      }

      const KeywordsModel = ctx.models('keywords');
     
      const keywordsEntity = await KeywordsModel.find({ campaignCode, active: true }).limit(1).exec();

      if(keywordsEntity.length===0){
        ctx.send(500, {
          resultCode: 0,
          errorCode: 1,
          serverTime: +new Date(),
          message: '该关键词已经达到最大使用次数',
          data: null,
        });
        return
      }
      
      // 关键词随机算法
      if(rewardGetten==='true'){
        if(keywordsEntity[0].VPTCount>0){
          keywordsEntity[0].VPTCount=keywordsEntity[0].VPTCount-1
        }else{
          keywordsEntity[0].active=false
        }
        let params={_id:keywordsEntity[0]._id}
        await KeywordsModel.findOneAndUpdate(params,{$set:keywordsEntity[0]},{new:true})
      }

      const result = keywordsEntity;

      ctx.send(200, {
        resultCode: 1,
        errorCode: 0,
        serverTime: +new Date(),
        message: 'success',
        data: result,
      });
    } catch (error) {
      console.log(error);
      ctx.send(500, {
        resultCode: 0,
        errorCode: 1,
        serverTime: +new Date(),
        message: error.toString(),
        data: null,
      });
    }
  }

  /**
   * 关键词当天使用次数
   * @param ctx {活动code，关键词}
   * @returns {Promise<void>}
   */
  async getSpendedVPT(ctx) {
    
  }

  /**
   * 刷新 关键词阀值
   * @param ctx {活动code，关键词，}
   * @returns {Promise<void>}
   */
  async refreshVPT(ctx) {
    
  }

  /**
   * 发送活动奖励
   * @param ctx {活动code，关键词，}
   * @returns {Promise<void>}
   */
  async sendAward(ctx) {

  }


}

export default new KeyWordController();
