'use strict'

import nanoid from 'nanoid';
import path from 'path';
import fs from 'fs';

const isProd = process.env.NODE_ENV === 'production';
import LRU from 'lru-cache';
import {createBundleRenderer} from "vue-server-renderer";

const resolve = file => path.resolve(__dirname, file);
//
// function createRenderer (bundle, options) {
//   // https://github.com/vuejs/vue/blob/dev/packages/vue-server-renderer/README.md#why-use-bundlerenderer
//   return createBundleRenderer(bundle, Object.assign(options, {
//     // for component caching
//     cache: new LRU({
//       max: 1000,
//       maxAge: 1000 * 60 * 15
//     }),
//     // this is only needed when vue-server-renderer is npm-linked
//     basedir: resolve('../../../dist'),
//     // recommended for performance
//     runInNewContext: false
//   }))
// }
function createRenderer (bundle, options) {
  return createBundleRenderer(bundle, Object.assign(options, {
    runInNewContext: false
  }))
};

let renderer;
const templatePath = resolve('../../../public/index.template.html');
const template = fs.readFileSync(templatePath, 'utf-8');
const bundle = require('../../../dist/vue-ssr-server-bundle.json');
const clientManifest = require('../../../dist/vue-ssr-client-manifest.json')
renderer = createRenderer(bundle, {
  template,
  clientManifest
})

export const index = async (ctx, next) => {
  const s = Date.now()

  ctx.res.setHeader("Content-Type", "text/html")

  const handleError = err => {
    if (err.url) {
      ctx.res.redirect(err.url)
    } else if (err.code === 404) {
      ctx.res.status = 404
    } else {
      // Render Error Page or Redirect
      ctx.res.status = 500
      console.error(`error during render : ${ctx.req.url}`)
      console.error(err.stack)
    }
  }

  const context = {
    title: 'Vue HN 2.0', // default title
    url: ctx.req.url
  }
  function renderToStringPromise() {
    return new Promise((resolve, reject) => {
      renderer.renderToString(context, (err, html) => {
        if (err) {
          console.log(err);
          handleError(err)
          reject(err)
        }
        if (!isProd) {
          console.log(`whole request: ${Date.now() - s}ms`);
        }
        resolve(html);
      });
    });
  }
  ctx.body = await renderToStringPromise();
}
//
// export const simple = async (ctx, next) => {
//
//   console.log(ctx.params)
//
//   const renderer = createRenderer()
//     //
//     // const app = new Vue({
//     //   data: {
//     //     url: ctx.req.url
//     //   },
//     //   template: `<div>访问的 URL 是： {{ url }}</div>`
//     // })
//
//     renderer.renderToString(main, (err, html) => {
//       if (err) {
//         ctx.res.status(500).end('Internal Server Error')
//         return
//       }
//       ctx.body = html
//     })
// }
