'use strict'
import {CampaignModel, ShareModal, ProductInfoModel} from "../../schemas";

export const index = async (ctx, next) => {

  try {
    const {params, query, querystring} = ctx
    if (!params || !params.campaignCode || !params.shareCode) {
      ctx.send(200, {
        code: 0,
        message: 'props must provide'
      })
      return;
    }

    const {campaignCode, shareCode} = params;
    const {platform, pagedebug} = query;

    const campaignEntity = await CampaignModel.findOne({campaignCode: campaignCode}).exec();

    if (!campaignEntity) {
      ctx.send(200, {
        code: 0,
        success: false,
        message: 'campaign not exist'
      })
      return;
    }

    const campaignObj = campaignEntity.toJSON()
    const {productId, campaignUrl} = campaignObj

    const productInfoEntity = await ProductInfoModel.findOne({productId: productId}).exec();

    if (!productInfoEntity) {
      ctx.send(200, {
        code: 0,
        success: false,
        message: 'productInfo not exist'
      })
      return;
    }
    const {productName} = productInfoEntity.toJSON()

    // const shareEntity = await ShareModal.findOne({shareCode: shareCode}).exec();

    let shareEntity
    if (platform) {
      shareEntity = await ShareModal.findOne({
        "shareCode": shareCode,
        "shareMetas.platform": platform || 'facebook'
      }, {"shareMetas.$": 1}).exec();
    } else {
      shareEntity = await ShareModal.findOne({
        "shareCode": shareCode
      }).exec();
    }

    if (!shareEntity) {
      ctx.send(200, {
        code: 0,
        success: false,
        message: 'share  not exist'
      })
      return;
    }

    const shareObj = shareEntity.toJSON()

    const {shareMetas, shareOriginUrl, pageType, shareType} = shareObj

    if (!shareObj || !shareMetas || !shareMetas[0].meta) {
      ctx.send(200, {
        code: 0,
        success: false,
        message: '分享不存在'
      })
      return;
    }

    const meta = {...campaignObj.meta, ...shareMetas[0].meta}

    const channel = '';
    const language = '';
    const countryCode = '';
    const moduleName = '';
    const inviteKey = '';
    const inviteKeyD = '';
    const inviteKeyID = '';
    const pid = '';
    const fullPath = '';

    switch (+shareType) {

      case 101:
        await ctx.render(`./download/${productName.toLowerCase()}/index`, {
          pageDebug: pagedebug || 0,
          querystring: querystring,
          meta,
          channel,
          language,
          countryCode,
          moduleName,
          inviteKey,
          inviteKeyD,
          inviteKeyID,
          pid,
          fullPath,
          originActUrl: shareOriginUrl || campaignUrl,
          // type: activityEntity.type,
          isDownLoad: true,
          pageType: pageType, // 1: 普通页面流程  2：可以在活动页面打不开的情况下，显示下载页面 3：在特定的浏览器中显示下载引导文案
          type: 1, // 1 : 下载活动页面 2: 下载
        })
        break
      case 100:
      default:

        await ctx.render('./share/share_blank', {
          pageDebug: pagedebug || 0,
          querystring: querystring,
          meta,
          channel,
          language,
          countryCode,
          moduleName,
          inviteKey,
          inviteKeyD,
          inviteKeyID,
          pid,
          fullPath,
          originActUrl: shareOriginUrl || campaignUrl,
          // type: activityEntity.type,
          isDownLoad: true,
          pageType: pageType, // 1: 普通页面流程  2：可以在活动页面打不开的情况下，显示下载页面 3：在特定的浏览器中显示下载引导文案
          type: 1, // 1 : 下载活动页面 2: 下载
        })
        break
    }

  } catch (e) {
    ctx.send(500, {message: e.toString()})
  }

}
