import { CampaignModel } from "../../schemas";
// 获取列表
export const fetchList = async (ctx, next) => {
  const { current, pageSize, ...params } = ctx.query;
  const { campaignPid, campaignName, productId, campaignCode } = params;
  try {
    const res = await CampaignModel.aggregate([
      {
        $lookup: {
          from: "product_infos", //关联那个集合
          localField: "productId", //当前集合关联的字段
          foreignField: "productId", //关联集合的关联字段
          as: "porductInfo", //最终结果放在items里
        },
      },
      {
        $match: {
          $and: [
            {
              campaignPid: { $regex: new RegExp(campaignPid, "gi") },
            },
            {
              campaignName: { $regex: new RegExp(campaignName, "gi") },
            },
            {
              productId: { $regex: new RegExp(productId, "gi") },
            },
            {
              campaignCode: { $regex: new RegExp(campaignCode, "gi") },
            },
          ],
        },
      },
      {
        $project: {
          "porductInfo.domainSet": 0,
          "porductInfo.productId": 0,
          "porductInfo._id": 0,
        },
      },
      {
        $facet: {
          pageInfo: [{ $count: "total" }],
          list: [{ $skip: Number(pageSize) * Number(current - 1) }, { $limit: Number(pageSize) }],
        },
      },
    ]).exec();
    ctx.send(200, {
      status: 200,
      msg: "查询成功",
      data: {
        list: res[0]?.list,
        total: res[0]?.pageInfo[0]?.total || 0,
      },
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
// 活动新增
export const campaignCtl2Add = async (ctx, next) => {
  try {
    const { body } = ctx.request;
    const {
      campaignName,
      campaignNickName,
      campaignUrl,
      campaignPid,
      productId,
      campaignCode,
      meta: { og_title, og_image, og_site_name, og_url, og_type, description, title },
    } = body;
    if (!campaignName || !campaignPid || !productId || !campaignCode) {
      ctx.send(200, {
        status: 100,
        msg: "productId campaignName campaignPid campaignCode must provide",
        data: null,
      });
      return;
    }
    const campaignEntity = await CampaignModel({
      campaignPid: campaignPid,
      campaignName: campaignName,
      campaignNickName: campaignNickName,
      campaignUrl: campaignUrl,
      productId: productId,
      campaignCode: campaignCode,
      meta: {
        og_title: og_title,
        og_image: og_image,
        og_site_name: og_site_name,
        og_url: og_url,
        og_type: og_type,
        description: description,
        title: title,
      },
    });
    let result = await campaignEntity.save().catch((err) => {
      ctx.throw(500, err);
    });

    ctx.body = {
      status: 200,
      msg: "success",
      data: {},
    };
  } catch (e) {
    if (e.message.indexOf("campaignName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100019,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("campaignNickName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100020,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("campaignCode_1 dup key") > -1) {
      ctx.send(200, {
        status: 100021,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("campaignPid_1 dup key") > -1) {
      ctx.send(200, {
        status: 100022,
        msg: "fail",
        data: {},
      });
    } else {
      ctx.send(500, { message: e.toString() });
    }
  }
};
// 活动编辑
export const campaignCtl2Upgrade = async (ctx, next) => {
  try {
    const { body } = ctx.request;
    const {
      _id,
      campaignName,
      campaignNickName,
      campaignUrl,
      campaignPid,
      productId,
      campaignCode,
      meta: { og_title, og_image, og_site_name, og_url, og_type, description, title },
    } = body;
    const campaignEntity = await CampaignModel.findOneAndUpdate(
      { _id: _id },
      {
        campaignName,
        campaignNickName,
        campaignUrl,
        campaignPid,
        productId,
        campaignCode,
        meta: {
          og_title,
          og_image,
          og_site_name,
          og_url,
          og_type,
          description,
          title,
        },
      }
    ).exec();
    if (!campaignEntity) {
      ctx.send(200, {
        status: 100,
        message: "not fount by campaignName",
        data: null,
      });
      return;
    }
    ctx.body = {
      status: 200,
      msg: "success",
      data: {},
    };
  } catch (e) {
    if (e.message.indexOf("campaignName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100019,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("campaignNickName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100020,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("campaignCode_1 dup key") > -1) {
      ctx.send(200, {
        status: 100021,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("campaignPid_1 dup key") > -1) {
      ctx.send(200, {
        status: 100022,
        msg: "fail",
        data: {},
      });
    } else {
      ctx.send(500, { message: e.toString() });
    }
  }
};
// 活动详情
export const campaignCtl2Detail = async (ctx, next) => {
  try {
    const { _id } = ctx.query;
    const res = await CampaignModel.findOne({ _id: _id }).exec();
    ctx.send(200, {
      status: 200,
      message: "success",
      data: res,
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
