import { CampaignModel, ShareModal, ProductInfoModel } from "../../schemas";
// 产品列表 (带分页)
export const fetchList = async (ctx, next) => {
  const { current, pageSize, ...params } = ctx.query;
  const { productName } = params;
  try {
    const res = await ProductInfoModel.aggregate([
      {
        $match: {
          productName: { $regex: new RegExp(productName, "gi") },
        },
      },
      {
        $facet: {
          pageInfo: [{ $count: "total" }],
          list: [{ $skip: Number(pageSize) * Number(current - 1) }, { $limit: Number(pageSize) }],
        },
      },
    ]).exec();
    ctx.send(200, {
      status: 200,
      msg: "查询成功",
      data: {
        list: res[0]?.list,
        total: res[0]?.pageInfo[0]?.total || 0,
      },
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
// 获取所有产品列表 (不带分页)
export const fetchAllList = async (ctx, next) => {
  try {
    const res = await ProductInfoModel.find().exec();
    ctx.send(200, {
      status: 200,
      msg: "查询成功",
      data: res,
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
// 产品新增
export const productAdd = async (ctx, next) => {
  try {
    const { body } = ctx.request;
    const { productId, productName, domainSet } = body;
    await ProductInfoModel({
      productId,
      productName,
      domainSet,
    })
      .save()
      .catch((err) => {
        ctx.throw(500, err);
      });

    ctx.send(200, {
      status: 200,
      msg: "success",
      data: {},
    });
  } catch (e) {
    if (e.message.indexOf("productName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100014,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("productId_1 dup key") > -1) {
      ctx.send(200, {
        status: 100015,
        msg: "fail",
        data: {},
      });
    } else {
      ctx.send(500, { message: e.toString() });
    }
  }
};
// 产品编辑
export const productUpgrade = async (ctx, next) => {
  try {
    const { body } = ctx.request;
    const { productId, productName, domainSet, _id } = body;
    if ((!productId && !productName) || !domainSet) {
      ctx.send(200, {
        status: 100,
        msg: "props must provide",
      });
      return;
    }
    const oldOne = await ProductInfoModel.findOne({
      productId,
      productName,
    }).exec();

    if (!oldOne) {
      ctx.send(200, {
        status: 100,
        msg: "productName not exist,upgrade fail",
      });
      return;
    }
    await ProductInfoModel.findOneAndUpdate(
      {
        _id,
      },
      {
        productId,
        productName,
        domainSet,
      }
    )
      .exec()
      .catch((err) => {
        ctx.throw(500, err);
      });

    ctx.send(200, {
      status: 200,
      msg: "success",
      data: {},
    });
  } catch (e) {
    if (e.message.indexOf("productName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100014,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("productId_1 dup key") > -1) {
      ctx.send(200, {
        status: 100015,
        msg: "fail",
        data: {},
      });
    } else {
      ctx.send(500, { message: e.toString() });
    }
  }
};
// 产品详情
export const productDetail = async (ctx, next) => {
  try {
    const { _id } = ctx.query;
    const res = await ProductInfoModel.findOne({ _id: _id }).exec();
    ctx.send(200, {
      status: 200,
      message: "success",
      data: res,
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
