import { CampaignModel, ShareModal } from "../../schemas";
import mongoose from "mongoose";
// 活动分享列表
export const fetchList = async (ctx, next) => {
  const { current, pageSize, ...params } = ctx.query;
  if (params.campaignRecordId) {
    params.campaignRecordId = mongoose.Types.ObjectId(params.campaignRecordId);
  }
  if (params.shareType) {
    params.shareType = Number(params.shareType);
  }
  if (params.pageType) {
    params.pageType = Number(params.pageType);
  }
  console.log(typeof params.shareType);
  try {
    const res = await ShareModal.aggregate([
      {
        $match: {
          $and: [params],
        },
      },
      {
        $facet: {
          pageInfo: [{ $count: "total" }],
          list: [{ $skip: Number(pageSize) * Number(current - 1) }, { $limit: Number(pageSize) }],
        },
      },
    ]).exec();
    ctx.send(200, {
      status: 200,
      msg: "查询成功",
      data: {
        list: res[0]?.list,
        total: res[0]?.pageInfo[0]?.total || 0,
      },
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
// 活动分享新增
export const shareAdd = async (ctx, next) => {
  try {
    const { body } = ctx.request;
    const {
      campaignRecordId,
      shareName,
      shareOriginUrl,
      shareType,
      shareNumber,
      shareCode,
      pageType,
      shareMetas,
    } = body;
    if (
      !campaignRecordId ||
      !shareName ||
      !shareMetas ||
      !shareOriginUrl ||
      !shareNumber ||
      !shareType ||
      !shareCode
    ) {
      ctx.send(200, {
        status: 100,
        message:
          "campaignRecordId || shareName || shareMetas || shareOriginUrl || shareNumber || shareType || shareCode props must provide",
      });
      return;
    }
    const campaignResult = await CampaignModel.findOne({ _id: campaignRecordId }).exec();
    if (!campaignResult) {
      ctx.send(200, {
        status: 100,
        msg: "not fount by campaignRecordId",
        data: null,
      });
      return;
    }
    const shareEntity = new ShareModal({
      campaignRecordId: campaignRecordId,
      shareName: shareName,
      shareOriginUrl: shareOriginUrl,
      shareType,
      shareNumber,
      pageType: pageType || "200",
      shareCode: shareCode,
      shareMetas: shareMetas,
      //   [
      //   {
      //     platform: 'facebook',
      //     areaCode: 'cn',
      //     meta: {
      //       og_title: 'facebook2',
      //       og_image: 'facebook2',
      //       og_site_name: 'facebook2',
      //       og_url: 'facebook2',
      //       og_type: 'facebook2',
      //       description: 'facebook2',
      //       title: 'facebook2',
      //     }
      //   }
      // ],
      // createUser: ctx.session().user,
    });
    await shareEntity.save().catch((err) => {
      ctx.throw(500, err);
    });
    ctx.body = {
      msg: "success",
      status: 200,
      data: {},
    };
  } catch (e) {
    if (e.message.indexOf("shareName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100016,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("shareCode_1 dup key") > -1) {
      ctx.send(200, {
        status: 100017,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("shareNumber_1 dup key") > -1) {
      ctx.send(200, {
        status: 100018,
        msg: "fail",
        data: {},
      });
    } else {
      ctx.send(500, { message: e.toString() });
    }
  }
};
// 活动分享编辑
export const shareUpgrade = async (ctx, next) => {
  try {
    const { body } = ctx.request;
    const {
      _id,
      campaignRecordId,
      shareName,
      shareOriginUrl,
      shareType,
      shareNumber,
      pageType,
      shareMetas,
      shareCode
    } = body;
    if (!body || !body._id) {
      ctx.send(200, {
        status: 100,
        msg: "props must provide",
      });
      return;
    }
    const campaignEntity = await ShareModal.findOneAndUpdate(
      { _id: _id },
      {
        campaignRecordId,
        shareName,
        shareOriginUrl,
        shareType,
        shareNumber,
        pageType,
        shareMetas,
        shareCode
      }
    ).exec();
    if (!campaignEntity) {
      ctx.send(200, {
        status: 100,
        message: "not fount by _id",
        data: null,
      });
      return;
    }
    ctx.body = {
      status: 200,
      msg: "success",
      data: {},
    };
  } catch (e) {
    if (e.message.indexOf("shareName_1 dup key") > -1) {
      ctx.send(200, {
        status: 100016,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("shareCode_1 dup key") > -1) {
      ctx.send(200, {
        status: 100017,
        msg: "fail",
        data: {},
      });
    } else if (e.message.indexOf("shareNumber_1 dup key") > -1) {
      ctx.send(200, {
        status: 100018,
        msg: "fail",
        data: {},
      });
    } else {
      ctx.send(500, { message: e.toString() });
    }
  }
};
// 活动分享详情
export const shareDetail = async (ctx, next) => {
  try {
    const { _id } = ctx.query;
    const res = await ShareModal.findOne({ _id: _id }).exec();
    ctx.send(200, {
      status: 200,
      message: "success",
      data: res,
    });
  } catch (e) {
    ctx.send(500, { message: e.toString() });
  }
};
