'use strict';

import compose from 'koa-compose';
import requestId from "@kasa/koa-request-id";
// import checkauth from './checkauth';
import cors from "kcors";
import Helmet from "koa-helmet";
import cookiesMiddleware from "universal-cookie-koa";
// import session from "koa-session";
// import ioredis from 'koa-2-ioredis';
import bodyParser from "koa-bodyparser";
import respond from "koa-respond";
import serve from "koa-static";
import views from "koa-views";
import logger from './logger';
import routes from '../routes';
import dbKeeper from './mongod';

export default function middleware() {
  return compose(
    [
      Helmet(),
      cookiesMiddleware(),
      bodyParser({
        enableTypes: ['json'],
        jsonLimit: '10mb',
        strict: true,
        extended: true,
        onerror: function (err, ctx) {
          if (err) {
            console.log(err)
          }
          ctx.throw('body parse error', 422)
        }
      }),
      requestId(),
      respond(),
      logger(),
      cors({credentials: true}),
      dbKeeper(),
      serve(__dirname + '/../../public'),
      serve(__dirname + '/../assets'),
      views(__dirname + '/../views', {extension: 'ejs'}),
      routes(),
    ]
  )
}
