'use strict';

import Router from 'koa-router';
import * as campaignCtl from '../controllers/campaign'
import * as campaignCtl2 from '../controllers/campaign2'
import * as product from '../controllers/product'
import * as share from '../controllers/share'
import userCtl from '../controllers/user'
import keywordCtl from '../controllers/campaign/keyword'

const router = new Router();

/**
 * user api
 */
router.post('/user/register', userCtl.register)
router.post('/user/login', userCtl.login)
router.get('/user/info', userCtl.getUserInfo)

/**
 * campaign api
*/
// router.post('/campaign/add', campaignCtl.addCampaign)
router.post('/campaign/removeByName', campaignCtl.removeCampaignByName)
router.post('/campaign/removeByCode', campaignCtl.removeCampaignByCode)
router.get('/campaign/getByName', campaignCtl.getCampaignByName)
router.get('/campaign/getByPid', campaignCtl.getCampaignByPid)
router.get('/campaign/getByCampaignCode', campaignCtl.getCampaignByCampaignCode)
router.post('/campaign/upgradeByName', campaignCtl.upgradeCampaignByName)
router.post('/campaign/upgradeByCode', campaignCtl.upgradeCampaignByCode)

/**
 * share api
 */
// router.post('/share/add', campaignCtl.addCampaignShare)
router.get('/share/getByName', campaignCtl.getShareByName)
router.get('/share/getByCampaignName', campaignCtl.getShareByCampaignName)
router.get('/share/getByOriginLink', campaignCtl.getShareByOriginLink)
router.get('/share/getByCode', campaignCtl.getShareByCode)
router.get('/share/getByContent', campaignCtl.getShareByContent)
router.post('/share/upgradeByName', campaignCtl.upgradeShareByName)
router.post('/share/upgradeByCode', campaignCtl.upgradeShareByCode)
router.post('/share/removeByName', campaignCtl.removeShareByName)
router.post('/share/removeByCode', campaignCtl.removeShareByCode)
// router.post('/invite/upgradeShareMetaByShareName', campaignCtl.addCampaignShare)


router.get('/share/getShareLink', campaignCtl.getShareLinkByPidAndNumber)

// router.post('/product/add', campaignCtl.addProduct)
// router.post('/product/upgrade', campaignCtl.upgradeProductDomainSet)
// router.post('/product/remove', campaignCtl.removeProductDomainSet)
// router.get('/product/find', campaignCtl.getProductDomainSet)


/**
 *  keywords 关键词活动
 */
router.post('/keywords/add', keywordCtl.addKeyWord)
router.get('/keywords/get', keywordCtl.getKeyWord)
router.get('/keywords/alreadyUsed', keywordCtl.getSpendedVPT)
router.post('/keywords/refresh', keywordCtl.refreshVPT)
router.post('/keywords/sendAward', keywordCtl.sendAward)

/**
 *  分享服务新api2.0
 * 
*/

// 产品列表 (带分页)
router.get('/product/list', product.fetchList)
// 产品列表 (不带分页)
router.get('/product/allList', product.fetchAllList)
// 产品新增
router.post('/product/add', product.productAdd)
// 产品编辑
router.post('/product/upgrade', product.productUpgrade)
// 产品详情
router.get('/product/detail', product.productDetail)


// 活动列表
router.get('/campaign/list', campaignCtl2.fetchList)
// 活动新增
router.post('/campaign/add', campaignCtl2.campaignCtl2Add)
// 活动编辑
router.post('/campaign/upgrade', campaignCtl2.campaignCtl2Upgrade)
// 活动详情
router.get('/campaign/detail', campaignCtl2.campaignCtl2Detail)


// 活动分享列表
router.get('/share/list', share.fetchList)
// 活动分享新增
router.post('/share/add', share.shareAdd)
// 活动分享编辑
router.post('/share/upgrade', share.shareUpgrade)
// 活动分享详情
router.get('/share/detail', share.shareDetail)









export default router;
