"use strict";
import mongoose from "mongoose";

const Schema = mongoose.Schema;
// import uuid from 'uuid';

const ShareSchema = new Schema({
  // shareId: {
  //   type: Schema.ObjectId
  // },
  // campaignRecordId: {type: String, default: ''},
  campaignRecordId: { type: Schema.ObjectId, ref: "campaign" },
  shareName: { type: String, default: "", unique: true },
  shareOriginUrl: { type: String, default: "" },
  shareType: { type: Number, default: 100 },
  shareNumber: { type: String, default: "1000", unique: true },
  pageType: { type: Number, default: 200 },
  shareCode: { type: String, default: "", unique: true },
  areaCodes: {
    type: Array,
    default: [],
  },
  sharePlatforms: {
    type: Array,
    default: [],
  },
  shareMetas: [
    {
      platform: { type: String, default: "facebook" },
      meta: {
        og_title: { type: String, default: "" },
        og_image: { type: String, default: "" },
        og_site_name: { type: String, default: "" },
        og_url: { type: String, default: "" },
        og_type: { type: String, default: "" },
        description: { type: String, default: "" },
        title: { type: String, default: "" },
      },
    },
  ],
  active: {
    type: Boolean,
    default: true,
  },
  expriation: {
    type: Date,
    dafault: Date.now(),
  },
  createUser: { type: Schema.ObjectId, ref: "user" },
  createAt: {
    type: Date,
    dafault: Date.now(),
  },
  updateAt: {
    type: Date,
    dafault: Date.now(),
  },
  upgradeNums: { type: Number, default: 0 },
  verified: {
    type: Boolean,
    default: true,
  },
});

const ShareChangeLogSchema = new Schema({
  shareInfo: {
    shareId: String,
    shareName: String,
  },
  userName: String,
  changeTime: {
    type: Date,
    dafault: Date.now(),
  },
  logInfo: String,
});

const ShareMetaSchema = new Schema({
  oriActShareId: {
    type: Schema.Types.ObjectId,
    ref: "campaign_share",
  },
  og_title: { type: String, default: "" },
  og_image: { type: String, default: "" },
  og_site_name: { type: String, default: "" },
  og_url: { type: String, default: "" },
  og_type: { type: String, default: "" },
  description: { type: String, default: "" },
  title: { type: String, default: "" },
});

// Defines a pre hook for the document.
ShareSchema.pre("save", function (next) {
  if (!this.updateAt) {
    this.createAt = this.updateAt = Date.now();
  } else {
    this.updateAt = Date.now();
  }
  this.upgradeNums = this.upgradeNums + 1;
  next();
});

exports.ShareMetaModal = mongoose.model("share_meta", ShareMetaSchema);
exports.ShareModal = mongoose.model("campaign_share", ShareSchema);
exports.ShareChangeLogModal = mongoose.model("share_change_log", ShareChangeLogSchema);
