import mongoose from "mongoose";
import {createJwtToken} from "./createJwtToken";
import UserService from '../user/UserService'
import bcrypt from 'bcrypt';

const User = mongoose.model('user')

class LoginService {

  async login(body) {
    if (!body.username || !body.password) {
      throw new Error('用户信息不完整');
    }
    // const user = await UserService.getUserByEmailAndPassword(data.email, data.password);
    const user = await UserService.getUserByUsername(body);

    if (!user) {
      throw new Error('用户信息不存在')
    }
    if (await bcrypt.compare(body.password, user.password)) {
      const jwt = await createJwtToken(user);
      let novuser = await UserService.setUserByToken({username: body.username, token: jwt});
      let {username} = user
      return {
        token: jwt,
        user: {username}
      };
    } else {
      throw new Error('密码错误');
    }
  }

  async getUserInfo(query) {
    if (!query.token) {
      throw new Error('验证信息不完整');
    }
    // const user = await UserService.getUserByEmailAndPassword(data.email, data.password);
    const user = await UserService.getUserByToken(query);

    if (!user) {
      throw new Error('用户信息不存在')
    }
    return user.toJSON();
  }

  async register(body) {
    if (!body.username || !body.password) {
      throw new Error(`expected an object with username, password but got: ${body}`)
    }
    let {username, password, roles} = body
    password = await bcrypt.hash(password, 5)
    let user = await UserService.getUserByUsername({username: body.username});
    if (!user) {
      const newUser = new User({username, password, roles});
      user = await newUser.save();
      return {
        message: '注册成功',
        user,
      }
    } else {
      throw new Error(`user already exist`)
    }
  }
}

export default new LoginService()
